@@ -2,11 +2,11 @@
 from subprocess import DEVNULL, run
 import warnings
 
-from .main import SqlCreds, to_sql
-from .utils import bcp
+from bcpandas.main import SqlCreds, to_sql
+from bcpandas.utils import bcp
 
 name = "bcpandas"
-__version__ = "1.4.0"
+__version__ = "2.0.0"
 
 
 # BCP check
