@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Created on Sat Aug  3 23:07:15 2019
 
@@ -16,7 +15,7 @@ import pandas as pd
 from pandas.io.sql import SQLDatabase, SQLTable
 import sqlalchemy as sa
 
-from .constants import (
+from bcpandas.constants import (
     IF_EXISTS_OPTIONS,
     IN,
     NEWLINE,
@@ -25,7 +24,7 @@ from .constants import (
     get_delimiter,
     get_quotechar,
 )
-from .utils import bcp, build_format_file, get_temp_file
+from bcpandas.utils import bcp, build_format_file, get_temp_file
 
 logger = logging.getLogger(__name__)
 
@@ -158,9 +157,9 @@ class SqlCreds:
 def _sql_item_exists(sql_type: str, schema: str, table_name: str, creds: SqlCreds) -> bool:
     _qry = dedent(
         """
-        SELECT * 
-        FROM INFORMATION_SCHEMA.{_typ}S 
-        WHERE TABLE_SCHEMA = '{_schema}' 
+        SELECT *
+        FROM INFORMATION_SCHEMA.{_typ}S
+        WHERE TABLE_SCHEMA = '{_schema}'
         AND TABLE_NAME = '{_tbl}'
         """.format(
             _typ=sql_type.upper(), _schema=schema, _tbl=table_name
@@ -209,8 +208,8 @@ def _handle_cols_for_append(
             pd.read_sql_query(
                 dedent(
                     """
-                SELECT COLUMN_NAME, ORDINAL_POSITION 
-                FROM INFORMATION_SCHEMA.COLUMNS 
+                SELECT COLUMN_NAME, ORDINAL_POSITION
+                FROM INFORMATION_SCHEMA.COLUMNS
                 WHERE TABLE_SCHEMA = '{_schema}'
                 AND TABLE_NAME = '{_tbl}'
             """.format(
